@@ -109,6 +109,9 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     :raises pyilt2.queryError: if the database returns an Error on a query
     """
     if prop:
+        #JOAO
+        print("prop = ",prop)
+        #JOAO
         if prop not in abr2prop.keys():
             #JOAO
             print("petara do baquila")
@@ -131,7 +134,7 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
         prp = prp
     )
     #JOAO
-    print(params)
+    print("params=",params)
     #JOAO
     r = requests.get(searchUrl, params=params)
     resDict = r.json()
